@@ -808,10 +808,12 @@ def get_color_contrast_with_gradients(
             bg_color,
         ]
     composite_color = ""
+
     # check all permutations of color combinations for contrast results
     for foreground in foreground_colors:
         for background in bg_colors:
             composite_color = ""
+
             # check for background alpha transparency
             bg_has_alpha = has_alpha_channel(background)
             if bg_has_alpha:
@@ -819,11 +821,17 @@ def get_color_contrast_with_gradients(
                 for i in range(len(ancestors) - 1, -1, -1):
                     ancestor = ancestors[i]
                     if len(ancestor) > 2:
-                        base_color = ancestor[2]
-                        composite_color = blend_alpha(base_color, background)
-                        container_bg = ancestor[2]
+                        if ancestor[2]:
+                            base_color = ancestor[2]
+                            composite_color = blend_alpha(
+                                base_color, background
+                            )
+                            container_bg = ancestor[2]
+                        elif "background:" in ancestor[-1]:
+                            input("Get something in here")
                 if not composite_color:
                     composite_color = blend_alpha(container_bg, background)
+
             # convert each to hex
             hex1 = to_hex(foreground)
             if composite_color:
